@@ -28,7 +28,7 @@
 
 
 getFunctionOrName <- function(FUN)
-     ## Try lattice namespace first? Does that happens automatically?
+     ## Try lattice namespace first? Does that happen automatically?
 {
     if (is.function(FUN)) FUN
     else if (is.character(FUN)) get(FUN)
@@ -44,24 +44,23 @@ checkArgsAndCall <- function(FUN, args) ## unnamed arguments not allowed
 }
 
 
-## Modified from methods::hasArg.  According to docs, name must be an
-## 'unquoted name', but a quoted string also seems to work.
+## Modified from methods::hasArg.
 hasGroupNumber <- function()
 {
-    aname <- name <- "group.number"
+    aname <- "group.number"
     fnames <- names(formals(sys.function(sys.parent())))
-    if(is.na(match(aname, fnames))) {
-        if(is.na(match("...", fnames)))
+    if (is.na(match(aname, fnames))) {
+        if (is.na(match("...", fnames)))
             FALSE
         else {
             dotsCall <- eval(quote(substitute(list(...))), sys.parent())
             !is.na(match(aname, names(dotsCall)))
         }
     }
-    else
-        eval(substitute(!missing(name)), sys.frame(sys.parent()))
+    else FALSE
 }
-    
+
+
 
 logLimits <- function(lim, base)
 {
@@ -120,7 +119,7 @@ oneway <-
 
 
 is.characterOrExpression <- function(x)
-    is.character(x) || is.expression(x)
+    is.character(x) || is.expression(x) || is.call(x) || is.symbol(x)
 
 
 
